@@ -7,6 +7,7 @@ use Data::Printer;
 use MARC::Convert::Wikidata::Object::Publisher;
 
 my $obj = MARC::Convert::Wikidata::Object::Publisher->new(
+        'id' => '000010003',
         'name' => 'Academia',
         'place' => 'Praha',
 );
@@ -19,6 +20,7 @@ p $obj;
 #     public methods (4) : can (UNIVERSAL), DOES (UNIVERSAL), isa (UNIVERSAL), VERSION (UNIVERSAL)
 #     private methods (1) : __ANON__ (Mo::is)
 #     internals: {
+#         id      "000010003",
 #         name    "Academia",
 #         place   "Praha"
 #     }
